QueryInfo

Trait QueryInfo 

pub trait QueryInfo {
    type Kind: QueryKind;

    // Required methods
    fn rotation(&self) -> Rotation;
    fn column_index(&self) -> usize;
}
Trait for retrieving information about cell queries.

Required Associated Types

type Kind: QueryKind

The kind of query this implementation provides information about.

Required Methods

fn rotation(&self) -> Rotation

Returns the rotation offset.

fn column_index(&self) -> usize

Returns the index of the column the queried cell belongs to.

Implementors