CellRef

Struct CellRef 

pub struct CellRef { /* private fields */ }
A reference to a cell in the circuit.

Implementations

Source

impl CellRef

pub fn absolute(col: usize, row: usize) -> Self

Creates a new cell reference using absolute coordinates.

pub fn relative(col: usize, base: usize, offset: usize) -> Self

Creates a new cell reference using coordinates relative to a row (usually the region’s first row).

pub fn row(&self) -> usize

Returns the absolute row the cell points to.

pub fn col(&self) -> usize

Returns the column number.

pub fn is_absolute(&self) -> bool

Returns true if is an absolute reference.

pub fn relativize(&self, base: usize) -> Self

Tries to convert an absolute reference into a relative reference w.r.t. the given base.

For a non-panicking version see try_relativize.

Panics

If the base is larger than the row number or if the reference is already relative.

pub fn try_relativize(&self, base: usize) -> Result<Self, CellError>

Tries to convert an absolute reference into a relative reference w.r.t. the given base.

Fails if the base is larger than the row number or if the reference is already relative.

pub fn absolutize(&self) -> Self

Converts the cell reference to an absolute reference.

If the reference is already absolute it does nothing.