pub trait ExpressionInfo: ExpressionTypes {
// Required methods
fn as_negation(&self) -> Option<&Self>;
fn as_fixed_query(&self) -> Option<&Self::FixedQuery>;
}Expand description
Trait for querying information about expressions.
Required Methods
Sourcefn as_negation(&self) -> Option<&Self>
fn as_negation(&self) -> Option<&Self>
If the expression is a negation returns a reference to the inner expression. Otherwise
should return None.
Sourcefn as_fixed_query(&self) -> Option<&Self::FixedQuery>
fn as_fixed_query(&self) -> Option<&Self::FixedQuery>
If the expression is a query to a fixed cells returns a reference to the query. Otherwise
should return None.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.